@@ -73,17 +73,6 @@ show_providers (ProviderConfigPrivate *priv)
 	g_object_unref (G_OBJECT (model));
 }
 
-/*
- * Callbacks
- */
-
-static void
-refresh_list_cb (GtkButton *button, gpointer user_data)
-{
-	ProviderConfigPrivate *priv = (ProviderConfigPrivate *) user_data;
-	show_providers (priv);
-}
-
 /*
  * Public functions
  */
@@ -104,9 +93,7 @@ provider_config_new (void)
 	g_object_set_data_full (G_OBJECT (provider), PROVIDER_CONFIG_DATA, priv,
 				(GDestroyNotify) g_free);
 
-	table = gnome_db_new_table_widget (2, 2, FALSE);
-        gtk_table_set_row_spacings (GTK_TABLE (table), 6);
-        gtk_table_set_col_spacings (GTK_TABLE (table), 6);
+	table = gnome_db_new_table_widget (2, 1, FALSE);
 	gtk_box_pack_start (GTK_BOX (provider), table, TRUE, TRUE, 0);
 
 	/* create the provider list */
@@ -120,26 +107,10 @@ provider_config_new (void)
 			  0, 0);
 	show_providers (priv);
 
-	/* add buttons */
-	box = gtk_vbutton_box_new ();
-	gtk_box_set_spacing (GTK_BOX (box), 6);
-	gtk_button_box_set_layout (GTK_BUTTON_BOX (box), GTK_BUTTONBOX_START);
-	gtk_widget_show (box);
-	gtk_table_attach (GTK_TABLE (table), box, 1, 2, 0, 1,
-			  GTK_FILL, GTK_FILL, 0, 0);
-
-	button = gnome_db_new_button_widget_from_stock (GTK_STOCK_PROPERTIES);
-	gtk_box_pack_start (GTK_BOX (box), button, FALSE, FALSE, 0);
-
-	button = gnome_db_new_button_widget_from_stock (GTK_STOCK_REFRESH);
-	g_signal_connect (G_OBJECT (button), "clicked",
-			  G_CALLBACK (refresh_list_cb), priv);
-	gtk_box_pack_start (GTK_BOX (box), button, FALSE, FALSE, 0);
-
 	/* add tip */
 	box = gnome_db_new_hbox_widget (FALSE, 6);
         gtk_container_set_border_width (GTK_CONTAINER (box), 6);
-	gtk_table_attach (GTK_TABLE (table), box, 0, 2, 1, 2,
+	gtk_table_attach (GTK_TABLE (table), box, 0, 1, 1, 2,
 			  GTK_FILL, GTK_FILL, 0, 0);
 
 	button = gtk_image_new_from_stock (GTK_STOCK_DIALOG_INFO, GTK_ICON_SIZE_DIALOG);
